@@ -3,9 +3,11 @@ knitr::opts_chunk$set(collapse = TRUE, comment = "#>")
 
 ## ------------------------------------------------------------------------
 library(haven)
-x <- labelled(c(1:3, tagged_na("a", "c", "z"), 4:1),
-              c("Agreement" = 1, "Disagreement" = 4, "First" = tagged_na("c"),
-                "Refused" = tagged_na("a"), "Not home" = tagged_na("z")))
+x <- labelled(
+  c(1:3, tagged_na("a", "c", "z"), 4:1),
+  c("Agreement" = 1, "Disagreement" = 4, "First" = tagged_na("c"),
+    "Refused" = tagged_na("a"), "Not home" = tagged_na("z"))
+  )
 
 print(x)
 
@@ -121,11 +123,9 @@ labels <- list(
 tmp <- set_labels(tmp, labels = labels)
 str(tmp)
 
-## ----echo=FALSE, message=FALSE-------------------------------------------
+## ----message=FALSE-------------------------------------------------------
 library(dplyr)
 library(sjmisc) # for frq()
-
-## ------------------------------------------------------------------------
 data(efc)
 
 efc %>% 
@@ -225,6 +225,7 @@ get_na(x)
 get_na(x, as.tag = TRUE)
 
 ## ------------------------------------------------------------------------
+library(sjmisc) # for replace_na()
 data(efc)
 str(efc$c84cop3)
 
